==========
ChangeLog
==========

All notable changes to this project will be documented in this file.

`Unreleased`_
=============

v0.2.1_
=======
* Autogenerate version.py
* Fix license classifier
* Use git tag for versioning

v0.2.0_
=======

* Remove sphinx_needs extension that depends numpy
* Reduce binary size to be half(~50MB) from previous(~95MB)

v0.1.0
======

* First public release.

.. _Unreleased: https://codeberg.org/miurahr/docubox/compare/v0.2.1...HEAD
.. _v0.2.1: https://codeberg.org/miurahr/docubox/compare/v0.2.0...v0.2.1
.. _v0.2.0: https://codeberg.org/miurahr/docubox/compare/v0.1.0...v0.2.0